@@ -13,7 +13,7 @@ use Udev::FFI::Monitor;
 use Udev::FFI::Enumerate;
 
 
-$Udev::FFI::VERSION = '0.099004';
+$Udev::FFI::VERSION = '0.099005';
 
 
 
@@ -223,7 +223,7 @@ Udev::FFI - Perl bindings for libudev using ffi.
     print Dumper(@a), "\n";
 
     if(@a) { # get major and minor
-        use Udev::FFI::Devnum qw(:all); # import major, minor and mkdev
+        use Udev::FFI::Devnum qw(:all); # import major, minor and makedev
 
         my $device = $udev->new_device_from_syspath($a[0]);
         if(defined $device) {
@@ -237,7 +237,7 @@ Udev::FFI - Perl bindings for libudev using ffi.
 
             $devnum = undef;
 
-            $devnum = mkdev($ma, $mi);
+            $devnum = makedev($ma, $mi);
             print "Devnum: $devnum\n";
 
 
@@ -305,8 +305,8 @@ database entry. The device is looked-up by its type and major/minor number.
 
 Return new L<Udev::FFI::Device> object or undef, if device does not exist.
 
-    use Udev::FFI::Devnum qw(mkdev);
-    my $device = $udev->new_device_from_devnum('b', mkdev(8, 1));
+    use Udev::FFI::Devnum qw(makedev);
+    my $device = $udev->new_device_from_devnum('b', makedev(8, 1));
 
 =item new_device_from_subsystem_sysname ( SUBSYSTEM, SYSNAME )
 
